Models
------

.. autoclass:: mailrobot.models.AbstractNamedModel
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: objects

.. autoclass:: mailrobot.models.Address
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: objects

.. autoclass:: mailrobot.models.MailBody
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: objects

.. autoclass:: mailrobot.models.Mail
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: objects, KEYFIELD_DEFAULTS

.. autoclass:: mailrobot.models.Signature
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: objects

